pub enum Balancing {
Strong(usize),
Weak(usize),
None,
}Expand description
Constraint on the level difference between neighboring nodes.
Variants
Strong(usize)
Level difference of at most n between nodes sharing a face, an edge
or a vertex.
Weak(usize)
Level difference of at most n between nodes sharing a face only.
None
No constraint on the level difference.